@@ -15,23 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 #include <QtGui>
+#include <QDebug>
+#include <QVBoxLayout>
+#include <QPushButton>
+#include <QMessageBox>
 
-#include <QToolTip>
-#include <QTimer>
-#include <QTreeWidgetItem>
-
-#include <kiconloader.h>
-#include <kpushbutton.h>
-#include <kmessagebox.h>
-#include <khbox.h>
-#include <kvbox.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <klocalizedstring.h>
 
 #include "docassistant.h"
 #include "docpostcard.h"
 #include "catalogselection.h"
-#include "headerselection.h"
 #include "textselection.h"
 #include "kraftsettings.h"
 #include "kataloglistview.h"
@@ -41,7 +34,6 @@
 #include "footertemplateprovider.h"
 #include "catalogtemplateprovider.h"
 #include "addresstemplateprovider.h"
-#include "addressselection.h"
 
 DocAssistant::DocAssistant( QWidget *parent ):
   QSplitter( parent ), mFullPreview( true ),
@@ -49,16 +41,15 @@ DocAssistant::DocAssistant( QWidget *parent ):
 {
   setOrientation( Qt::Vertical );
 
-  QWidget *w = new QWidget;
-  addWidget( w );
+  QWidget *topWidget = new QWidget;
   QVBoxLayout *topVBox = new QVBoxLayout;
-  w->setLayout( topVBox );
+  topVBox->setMargin(0);
+  topWidget->setLayout( topVBox );
 
   QHBoxLayout *buttonLayout = new QHBoxLayout;
   topVBox->addLayout( buttonLayout );
-  buttonLayout->setMargin( KDialog::marginHint()/2 );
 
-  KPushButton *pb = new KPushButton( i18n( "Show Templates" ) );
+  QPushButton *pb = new QPushButton( i18n( "Show &Templates" ) );
   buttonLayout->addWidget( pb );
   connect( pb, SIGNAL( toggled( bool ) ),
            this, SLOT( slotToggleShowTemplates( bool ) ) );
@@ -66,23 +57,25 @@ DocAssistant::DocAssistant( QWidget *parent ):
   pb->setToolTip( i18n( "Show mask to create or select templates to be used in the document" ) );
 
   buttonLayout->addStretch();
-
+  topVBox->addLayout(buttonLayout);
   mPostCard = new DocPostCard;
-
   mPostCard->slotSetMode( DocPostCard::Full, KraftDoc::Header );
   // setResizeMode( vb /* mPostCard->view() */, KeepSize );
 
-  connect( mPostCard, SIGNAL( completed() ),
-           this,  SLOT( slotRenderCompleted() ) );
+  topVBox->addWidget(mPostCard);
 
-  topVBox->addWidget( mPostCard->view() );
+  addWidget(topWidget);
 
-  // KVBox *stackVBox = new KVBox( this );
   mTemplatePane = new QWidget;
   QVBoxLayout *bottomVBox = new QVBoxLayout;
+  bottomVBox->setMargin(0);
+
   mTemplatePane->setLayout( bottomVBox );
   addWidget( mTemplatePane );
 
+  setStretchFactor(0, 0);
+  setStretchFactor(1, 0);
+
   mWidgetStack = new QStackedWidget;
 
   bottomVBox->addWidget( mWidgetStack );
@@ -96,65 +89,62 @@ DocAssistant::DocAssistant( QWidget *parent ):
   connect( mCatalogSelection, SIGNAL( selectionChanged(QTreeWidgetItem*,QTreeWidgetItem*) ),
            this,  SLOT( slotCatalogSelectionChanged(QTreeWidgetItem*,QTreeWidgetItem*) ) );
 
-  mHeaderSelection = new HeaderSelection;
-  mWidgetStack->addWidget( mHeaderSelection );
+  mHeaderSelector = new TextSelection( 0, KraftDoc::Header );
+  mWidgetStack->addWidget( mHeaderSelector );
 
-  connect( mHeaderSelection, SIGNAL( addressSelectionChanged() ),
-           this, SLOT( slotAddressSelectionChanged() ) );
-  connect( mHeaderSelection, SIGNAL(textSelectionChanged( QTreeWidgetItem* ) ),
-           this, SLOT( slotTextsSelectionChanged( QTreeWidgetItem* ) ) );
-  connect( mHeaderSelection->textSelection(), SIGNAL( actionCurrentTextToDoc() ),
-           this,  SLOT( slotAddToDocument() ) );
-  connect( mHeaderSelection, SIGNAL( doubleClickedOnItem() ),
-           this, SLOT( slotAddToDocument() ) );
+  connect( mHeaderSelector, SIGNAL(validTemplateSelected() ),
+           this, SLOT( slotTemplateSelectionChanged() ) );
+  connect( mHeaderSelector, SIGNAL(editCurrentTemplate()),
+           this, SLOT(slotEditTemplate()));
 
   mFooterSelection = new TextSelection( 0, KraftDoc::Footer );
   mWidgetStack->addWidget( mFooterSelection );
 
-  connect( mFooterSelection, SIGNAL( textSelectionChanged( QTreeWidgetItem* ) ),
-           this, SLOT( slotTextsSelectionChanged( QTreeWidgetItem* ) ) );
+  connect( mFooterSelection, SIGNAL(validTemplateSelected()),
+           this, SLOT(slotTemplateSelectionChanged()));
+  connect( mFooterSelection, SIGNAL(editCurrentTemplate()),
+           this, SLOT(slotEditTemplate()));
   connect( mFooterSelection, SIGNAL( actionCurrentTextToDoc() ),
            this,  SLOT( slotAddToDocument() ) );
 
-  mWidgetStack->setCurrentWidget( mHeaderSelection );
   connect( mPostCard, SIGNAL( selectPage( int ) ),
            this,  SLOT( slotSelectDocPart( int ) ) );
 
   QHBoxLayout *butHBox2 = new QHBoxLayout;
   bottomVBox->addLayout( butHBox2 );
 
-  butHBox2->setSpacing( KDialog::spacingHint() );
-  KIcon icons = KIcon( "go-previous" ); // KDE 4 icon name: go-previous
-  mPbAdd  = new KPushButton( icons, QString() );
+  QIcon icons = QIcon::fromTheme( "go-previous" ); // KDE 4 icon name: go-previous
+  mPbAdd  = new QPushButton( icons, QString() );
   mPbAdd->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
   connect( mPbAdd, SIGNAL( clicked() ), this, SLOT( slotAddToDocument() ) );
   butHBox2->addWidget( mPbAdd );
   mPbAdd->setToolTip( i18n( "Add a template to the document" ) );
 
-  icons = KIcon( "document-new" );
-  mPbNew  = new KPushButton( icons, QString() ); // KDE 4 icon name: document-new
+  icons = QIcon::fromTheme( "document-new" );
+  mPbNew  = new QPushButton( icons, QString() ); // KDE 4 icon name: document-new
   mPbNew->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
   connect( mPbNew, SIGNAL( clicked() ), this, SLOT( slotNewTemplate() ) );
-  mPbNew->setToolTip( i18n( "Create a new template (type depending)" ) );
+  mPbNew->setToolTip( i18n( "Create a new template" ) );
   butHBox2->addWidget( mPbNew );
 
-  icons = KIcon( "document-properties" );
-  mPbEdit  = new KPushButton( icons, QString() ); // KDE 4 icon name: document-properties
+  icons = QIcon::fromTheme( "document-properties" );
+  mPbEdit  = new QPushButton( icons, QString() ); // KDE 4 icon name: document-properties
   mPbEdit->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
   connect( mPbEdit, SIGNAL( clicked() ), this, SLOT( slotEditTemplate() ) );
-  mPbEdit->setToolTip( i18n( "Edit the selected template (type depending)" ) );
+  mPbEdit->setToolTip( i18n( "Edit the current template" ) );
   butHBox2->addWidget( mPbEdit );
 
-  icons = KIcon( "edit-delete" );
-  mPbDel  = new KPushButton( icons, QString() ); // KDE 4 icon name: edit-delete
+  icons = QIcon::fromTheme( "edit-delete" );
+  mPbDel  = new QPushButton( icons, QString() ); // KDE 4 icon name: edit-delete
   mPbDel->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
   connect( mPbDel, SIGNAL( clicked() ), this, SLOT( slotDeleteTemplate() ) );
-  mPbDel->setToolTip( i18n( "Delete the selected template (type depending)" ) );
+  mPbDel->setToolTip( i18n( "Delete the current template" ) );
   butHBox2->addWidget( mPbDel );
 
   butHBox2->addStretch();
 
   mPbAdd->setEnabled( false );
+  mPbNew->setEnabled( false );
   mPbEdit->setEnabled( false );
   mPbDel->setEnabled( false );
 
@@ -170,11 +160,7 @@ DocAssistant::DocAssistant( QWidget *parent ):
            this,  SLOT( slotHeaderTextToDocument( const DocText& ) ) );
   connect( mHeaderTemplateProvider, SIGNAL( deleteHeaderText( const DocText& ) ),
            this,  SLOT( slotHeaderTextDeleted( const DocText& ) ) );
-
-  connect( mHeaderSelection, SIGNAL( switchedToHeaderTab( HeaderSelection::HeaderTabType ) ),
-           this, SLOT( slSetHeaderTemplateProvider( HeaderSelection::HeaderTabType ) ) );
-
-  mHeaderTemplateProvider->setSelection( mHeaderSelection->textSelection() );
+  mHeaderTemplateProvider->setSelection( mHeaderSelector );
 
   mFooterTemplateProvider = new FooterTemplateProvider( parent );
 
@@ -195,55 +181,47 @@ DocAssistant::DocAssistant( QWidget *parent ):
   connect( mCatalogTemplateProvider,  SIGNAL( templatesToDocument(Katalog*,CatalogTemplateList) ),
            this, SIGNAL( templatesToDocument(Katalog*,CatalogTemplateList) ) );
 
-  mAddressTemplateProvider = new AddressTemplateProvider( parent );
-  connect( mHeaderSelection->addressSelection(), SIGNAL( addressSelected( const Addressee& ) ),
-           mAddressTemplateProvider, SLOT( slotSetCurrentAddress( const Addressee& ) ) );
-
-  connect( mAddressTemplateProvider, SIGNAL( addressToDocument( const Addressee& ) ),
-           this, SLOT( slotAddressToDocument( const Addressee& ) ) );
-
   mCurrTemplateProvider = mHeaderTemplateProvider;
 
-  // mMainSplit->setSizes( KraftSettings::self()->assistantSplitterSetting() );
+  const QList<int> sizes = KraftSettings::self()->assistantSplitterSetting();
+  if( sizes.count() > 0 ) {
+      setSizes( sizes );
+  }
   mTemplatePane->hide();
 }
 
 void DocAssistant::slotAddToDocument()
 {
-  kDebug() << "SlotAddToDocument called!" << endl;
+  // qDebug () << "SlotAddToDocument called!" << endl;
   if ( mCurrTemplateProvider ) {
     mCurrTemplateProvider->slotTemplateToDocument();
   }
 }
 
-void DocAssistant::slotAddressSelectionChanged()
+void DocAssistant::slotTemplateSelectionChanged( )
 {
-  kDebug() << "A address template was selected!" << endl;
-  if ( mHeaderSelection->textSelection()->textsListView()->selectedItems().count() ) {
-    mPbAdd->setEnabled( true );
-    mPbEdit->setEnabled( true );
-    mPbDel->setEnabled( false );
-
-  }
-}
-
-void DocAssistant::slotTextsSelectionChanged( QTreeWidgetItem *item )
-{
-  if ( item ) {
-    mPbAdd->setEnabled( true );
-    mPbEdit->setEnabled( true );
-    mPbDel->setEnabled( true );
-  } else {
-    mPbAdd->setEnabled( false );
+  if( mActivePage == KraftDoc::Positions ) { // no editing on the catalogs
+    mPbNew->setEnabled( false );
     mPbEdit->setEnabled( false );
     mPbDel->setEnabled( false );
+  } else {
+    bool mv = false;
+    if( mActivePage == KraftDoc::Header ) {
+      mv = mHeaderSelector->validSelection();
+    } else if( mActivePage == KraftDoc::Footer ) {
+      mv = mFooterSelection->validSelection();
+    }
+    mPbAdd->setEnabled( mv );
+    mPbNew->setEnabled( true );
+    mPbEdit->setEnabled( mv );
+    mPbDel->setEnabled( mv );
   }
 }
 
 void DocAssistant::slotCatalogSelectionChanged(QTreeWidgetItem *current ,QTreeWidgetItem *)
 {
   // enable the move-to-document button.
-  kDebug() << "catalog position selection changed!" << endl;
+  // qDebug () << "catalog position selection changed!" << endl;
   if ( current ) {
     mPbAdd->setEnabled( true );
   } else {
@@ -262,13 +240,13 @@ void DocAssistant::slotNewTemplate()
 void DocAssistant::slotNewHeaderDocText( const DocText& dt )
 {
   /* show in list of texts in the GUI */
-  mHeaderSelection->textSelection()->addNewDocText( dt );
+  mHeaderSelector->addNewDocText( dt );
 }
 
 /* called with a changed text that needs to be updated in the view */
 void DocAssistant::slotUpdateHeaderDocText( const DocText& dt )
 {
-  mHeaderSelection->textSelection()->updateDocText( dt );
+  mHeaderSelector->updateDocText( dt );
 }
 
 /* the user hit "add to document" to use a header text template */
@@ -296,15 +274,10 @@ void DocAssistant::slotFooterTextToDocument( const DocText& dt )
   emit footerTextTemplate( dt.text() );
 }
 
-void DocAssistant::slotAddressToDocument( const Addressee& adr )
-{
-  emit addressTemplate( adr );
-}
-
 /* Slot that initiates an edit */
 void DocAssistant::slotEditTemplate()
 {
-  kDebug() << "Editing a template using the currentTemplProvider" << endl;
+  // qDebug () << "Editing a template using the currentTemplProvider" << endl;
   if ( mCurrTemplateProvider ) {
     mCurrTemplateProvider->slotSetDocType( mDocType );
     mCurrTemplateProvider->slotEditTemplate();
@@ -314,46 +287,33 @@ void DocAssistant::slotEditTemplate()
 /* slot that initialises a delete, called from the delete button */
 void DocAssistant::slotDeleteTemplate()
 {
-  if ( KMessageBox::warningYesNo( this, i18n( "Do you really want to delete the "
-                                            "template permanently? There is no way "
-                                              "to recover!" ) )
-       == KMessageBox::No  )
-  {
-    return;
-  }
 
-  if ( mCurrTemplateProvider ) {
-    mCurrTemplateProvider->slotDeleteTemplate();
-  }
-}
+    QMessageBox msgBox;
+    msgBox.setText(i18n( "Do you really want to delete the template permanently?\n"
+                         "It can not be recovered."));
+    msgBox.setStandardButtons(QMessageBox::Yes| QMessageBox::No);
+    msgBox.setDefaultButton(QMessageBox::Yes);
+    int ret = msgBox.exec();
 
-void DocAssistant::slSetHeaderTemplateProvider( HeaderSelection::HeaderTabType t )
-{
+    if ( ret == QMessageBox::No ) {
+        return;
+    }
 
-  // go out here if it is not the header doc part, sometimes the tab widget
-  // seems to throw the signal a bit unwanted what results in a current template
-  // provider that points to header however we're on the footer page
-  if ( mActivePage != KraftDoc::Header ) {
-    return;
-  }
-
-  if ( t == HeaderSelection::AddressTab ) {
-    mCurrTemplateProvider = mAddressTemplateProvider;
-  } else if ( t == HeaderSelection::TextTab ) {
-    mCurrTemplateProvider = mHeaderTemplateProvider;
-  } else {
-    kDebug() << "Unknown HeaderSelection type" << endl;
-  }
+    if ( mCurrTemplateProvider ) {
+        mCurrTemplateProvider->slotDeleteTemplate();
+    }
 }
 
 void DocAssistant::slotHeaderTextDeleted( const DocText& /* dt */)
 {
-  mHeaderSelection->textSelection()->deleteCurrentText();
+  mHeaderSelector->deleteCurrentText();
+  slotTemplateSelectionChanged( ); // disable the edit buttons etc.
 }
 
 void DocAssistant::slotFooterTextDeleted( const DocText& /* dt */)
 {
   mFooterSelection->deleteCurrentText();
+  slotTemplateSelectionChanged( ); // disable the edit buttons etc.
 }
 
 /* slot that opens the template details in case on == true */
@@ -376,87 +336,40 @@ void DocAssistant::slotToggleShowTemplates( bool on )
   emit toggleShowTemplates( on );
 }
 
-void DocAssistant::slotRenderCompleted()
-{
-  // kDebug() << "Render completed: " << mPostCard->view()->contentsHeight() << endl;
-
-#if 0
-  /* This is unfortunately not working because contentsHeight is always as
-     heigh as the viewport is. Must be fixed in khtmlpart. */
-  QList<int> sizes;
-  sizes << mPostCard->view()->contentsHeight();
-  setSizes( sizes );
-#endif
-
-}
-
 DocPostCard *DocAssistant::postCard()
 {
-  return mPostCard;
+    return mPostCard;
 }
 
 CatalogSelection* DocAssistant::catalogSelection()
 {
-  return mCatalogSelection;
+    return mCatalogSelection;
 }
 
 /* sets the Part of the doc, eg. Header, Footer */
 void DocAssistant::slotSelectDocPart( int p )
 {
   mActivePage = p;
-  // change the currentTemplateProvider variable.
-  mPbEdit->setEnabled( false );
-  mPbDel->setEnabled( false );
-
-  if ( p == KraftDoc::Header ) {
-    if(mHeaderSelection->currentIndex() == 0)
-      slSetHeaderTemplateProvider( HeaderSelection::AddressTab );
-    else
-      slSetHeaderTemplateProvider( HeaderSelection::TextTab );
-
-    mPbNew->setEnabled( true );
-    if ( mHeaderSelection->itemSelected() ) {
-      kDebug() << "Enabling Edit and Del for Header" << endl;
-      mPbEdit->setEnabled( true );
-      mPbDel->setEnabled( true );
-    }
-
-  } else if ( p == KraftDoc::Positions ) {
+  if( mActivePage == KraftDoc::Header ) {
+    mCurrTemplateProvider = mHeaderTemplateProvider;
+  } else if( mActivePage == KraftDoc::Positions ) {
     mCurrTemplateProvider = mCatalogTemplateProvider;
-    mPbNew->setEnabled( false );
-  } else if ( p == KraftDoc::Footer ) {
+  } else if( mActivePage == KraftDoc::Footer ) {
     mCurrTemplateProvider = mFooterTemplateProvider;
-    mPbNew->setEnabled( true );
-
-    if ( mFooterSelection->textsListView()->selectedItems().count() ) {
-      mPbEdit->setEnabled( true );
-      mPbDel->setEnabled( true );
-    }
+  } else {
+    // qDebug () << "Alert: Unknown document part id: " << p;
   }
-
   emit selectPage( p );
   slotToggleShowTemplates( !mFullPreview );
+  slotTemplateSelectionChanged( ); // hide the add, edit- and del buttons
 }
 
 /* Doc Type like offer, invoice etc. */
 void DocAssistant::slotSetDocType( const QString& type )
 {
   mDocType = type;
-  mHeaderSelection->slotSelectDocType( type );
+  mHeaderSelector->slotSelectDocType( type );
   mFooterSelection->slotSelectDocType( type );
-
-  // nothing is selected.
-  bool selector = false;
-  if ( mActivePage == KraftDoc::Header && mHeaderSelection->itemSelected() ) {
-    selector = true;
-  }
-  if ( mActivePage == KraftDoc::Footer && mFooterSelection->textsListView()->selectedItems().count() ) {
-    selector = true;
-  }
-
-  mPbAdd->setEnabled( true );
-  mPbEdit->setEnabled( selector );
-  mPbDel->setEnabled( selector );
 }
 
 void DocAssistant::slotShowCatalog( )
@@ -468,7 +381,7 @@ void DocAssistant::slotShowCatalog( )
 void DocAssistant::slotShowHeaderTemplates()
 {
   setFullPreview( false, KraftDoc::Header );
-  mWidgetStack->setCurrentWidget( mHeaderSelection );
+  mWidgetStack->setCurrentWidget( mHeaderSelector );
 }
 
 void DocAssistant::slotShowFooterTemplates()
@@ -479,25 +392,33 @@ void DocAssistant::slotShowFooterTemplates()
 
 void DocAssistant::setFullPreview( bool setFull, int id )
 {
-  if ( setFull ) {
-    /* remember the sizes used before */
-    if ( mTemplatePane->isVisible() ) {
-      // kDebug() << "Writing mSplitterSizes: " << mMainSplit->sizes() << endl;
-      // KraftSettings::self()->setAssistantSplitterSetting( mMainSplit->sizes() );
-    //  KraftSettings::self()->writeConfig();
-    }
+    if ( setFull ) {
+        /* remember the sizes used before */
+        saveSplitterSizes();
 
-    mTemplatePane->hide();
-    mPostCard->slotSetMode( DocPostCard::Full, id );
-    mFullPreview = true;
-  } else {
-    mTemplatePane->show();
-    mPostCard->slotSetMode( DocPostCard::Mini, id );
+        mTemplatePane->hide();
+        mPostCard->slotSetMode( DocPostCard::Full, id );
+        mFullPreview = true;
+    } else {
+        mTemplatePane->show();
+        mPostCard->slotSetMode( DocPostCard::Mini, id );
 
-    if ( KraftSettings::self()->assistantSplitterSetting().size() == 2 ) {
-      // mMainSplit->setSizes( KraftSettings::self()->assistantSplitterSetting() );
+        if ( KraftSettings::self()->assistantSplitterSetting().size() == 2 ) {
+            QList<int> sizes = KraftSettings::self()->assistantSplitterSetting();
+            if( sizes.contains(0)) {
+                sizes[0] = 50;
+                sizes[1] = 50;
+            }
+            setSizes( sizes );
+        }
+        mFullPreview = false;
     }
-    mFullPreview = false;
-  }
 }
 
+void DocAssistant::saveSplitterSizes()
+{
+    if( mTemplatePane->isVisible() ) {
+        const QList<int> s = sizes();
+        KraftSettings::self()->setAssistantSplitterSetting( s );
+    }
+}
