@@ -88,6 +88,9 @@ FlosTemplDialog::FlosTemplDialog( QWidget *parent, bool modal )
   m_fixParts->header()->setResizeMode(QHeaderView::ResizeToContents);
   m_matParts->header()->setResizeMode(QHeaderView::ResizeToContents);
 
+  // disable for now, not used
+  cbMwst->setVisible(false);
+  m_mwstLabel->setVisible(false);
   setupConnections();
   setButtonIcons();
 }
@@ -159,6 +162,8 @@ void FlosTemplDialog::setTemplate( FloskelTemplate *t, const QString& katalognam
   QString chap = m_katalog->chapterName(dbID(chapID));
   cbChapter->setCurrentIndex(cbChapter->findText( chap ));
 
+  m_manualPriceVal->setSuffix(m_katalog->locale()->currencySymbol());
+
   /* Text of the template */
   m_text->setText( t->getText());
 
@@ -170,16 +175,12 @@ void FlosTemplDialog::setTemplate( FloskelTemplate *t, const QString& katalognam
   m_manualPriceVal->setValue( t->unitPrice().toDouble());
 
   /* Kind of Calculation: Manual or calculated?  */
-
-  if( t->calcKind() == CatalogTemplate::ManualPrice )
-  {
+  _origCalcType = m_template->calcKind();
+  if( t->calcKind() == CatalogTemplate::ManualPrice ) {
     slCalcOrFix(0);
     m_rbManual->setChecked(true);
     m_rbCalculation->setChecked(false);
-
-  }
-  else /* if( t->calcKind() == Calculation ) */
-  {
+  } else {
     slCalcOrFix(1);
     m_rbManual->setChecked(false);
     m_rbCalculation->setChecked(true);
@@ -187,17 +188,15 @@ void FlosTemplDialog::setTemplate( FloskelTemplate *t, const QString& katalognam
 
   /* set up the different calculation parts */
   setCalcparts();
+  _calcPartsModified = false;
 
   /* set text */
   slSetNewText();
 
+  m_addTime->setChecked( m_template->hasTimeslice() );
   m_text->setFocus();
   m_text->selectAll();
 
-  pbRundPreis->setEnabled(false);
-
-  //Fixme: Only set this to true if something really changed
-  modified = true;
 }
 
 void FlosTemplDialog::setCalcparts( )
@@ -258,11 +257,11 @@ void FlosTemplDialog::refreshPrices()
   else if( m_template->calcKind() == CatalogTemplate::Calculation )
   {
     int benefit = spBenefit->value();
-    QString benefitStr = i18n("(+%1%)").arg(benefit);
+    QString benefitStr = i18n("(+%1%)", benefit);
 
     if( benefit < 0 )
     {
-      benefitStr = "<font color=\"red\">"+i18n("%1%").arg(benefit)+"</font>";
+      benefitStr = QLatin1String("<font color=\"red\">")+i18n("%1%", benefit)+QLatin1String("</font>");
     }
     benefitStr += i18n(": ");
     t += benefitStr;
@@ -272,6 +271,7 @@ void FlosTemplDialog::refreshPrices()
     // qDebug () << "ERR: unknown calculation type!" << endl;
   }
   m_resPreisName->setText(t);
+  m_resPreisName->setTextFormat(Qt::RichText);
 
   /* set Price */
   t = m_template->unitPrice().toString( m_katalog->locale() );
@@ -288,6 +288,9 @@ void FlosTemplDialog::refreshPrices()
   g = m_template->costsByCalcPart( KALKPART_MATERIAL );
   m_textMaterialPart->setText(g.toString( m_katalog->locale() ));
 
+  // Benefit
+  double b = m_template->getBenefit();
+  spBenefit->setValue( qRound(b));
 }
 
 FlosTemplDialog::~FlosTemplDialog( )
@@ -297,88 +300,97 @@ FlosTemplDialog::~FlosTemplDialog( )
   delete m_matPartDialog;
 }
 
+// Check if the template was modified in the dialog
+bool FlosTemplDialog::templModified()
+{
+    bool modified = false;
+
+    QString str = m_text->toPlainText();
+    modified = str != m_template->getText();
+
+    modified = modified || (m_unit->currentText() != m_template->unit().einheitSingular());
+
+    modified = modified || (m_addTime->isChecked() != m_template->hasTimeslice());
+
+    str = spBenefit->cleanText();
+    bool b;
+    int new_val = str.toInt(&b);
+    modified = modified || ( b && new_val != qRound(m_template->getBenefit()));
+
+    // calculation kind
+    CatalogTemplate::CalculationType currCalcType = m_template->calcKind();
+    modified = modified || (currCalcType != _origCalcType);
+
+    modified = modified || _calcPartsModified;
+
+    return modified;
+}
+
 void FlosTemplDialog::accept()
 {
-  if( m_template ) {
-    // qDebug () << "Saving template ID " << m_template->getTemplID() << endl;
+    if( m_template ) {
+        // qDebug () << "Saving template ID " << m_template->getTemplID() << endl;
 
-    QString h;
-    h = m_text->toPlainText();
+        QString h;
+        h = m_text->toPlainText();
 
-    if( h != m_template->getText() ) {
-      // qDebug () << "Template Text dirty -> update" << endl;
-      m_template->setText( h );
+        if( h != m_template->getText() ) {
+            // qDebug () << "Template Text dirty -> update" << endl;
+            m_template->setText( h );
+        }
+
+        h = m_unit->currentText();
+        if( h != m_template->unit().einheitSingular()) {
+            // qDebug () << "Template Einheit dirty -> update to " << h << endl;
+            m_template->setUnitId( UnitManager::self()->getUnitIDSingular(h));
+        }
+
+        /* count time */
+        bool c = m_addTime->isChecked();
+        if( c != m_template->hasTimeslice() ) {
+            m_template->setHasTimeslice(c);
+        }
+
+        /* benefit */
+        h = spBenefit->cleanText();
+        bool b;
+        int new_val = h.toInt(&b);
+        if( b && new_val != qRound(m_template->getBenefit())) {
+            m_template->setBenefit(new_val);
+            // qDebug () << "benefit dirty ->update to " << g << endl;
+        }
+
+        // Calculationtype
+        int selId = m_gbPriceSrc->checkedId();
+        CatalogTemplate::CalculationType calcType = CatalogTemplate::Unknown;
+        if( selId == 0 ) {
+            calcType = CatalogTemplate::ManualPrice;
+        } else if( selId == 1 ) {
+            calcType = CatalogTemplate::Calculation;
+        } else {
+            // qDebug () << "ERROR: Calculation type not selected, id is " << selId << endl;
+        }
+        m_template->setCalculationType( calcType );
+
+        // reread the manual price
+        double dd = m_manualPriceVal->value();
+        m_template->setManualPrice( Geld( dd ) );
+
+        h = cbChapter->currentText();
+        // qDebug () << "catalog chapter is " << h << endl;
+
+        _calcPartsModified = false;
+
+        if( m_template->save() ) {
+            emit( editAccepted( m_template ) );
+            KatalogMan::self()->notifyKatalogChange( m_katalog, m_template->getTemplID() );
+        } else {
+            QMessageBox::warning(0, i18n("Template Error"), i18n("Saving of this template failed, sorry"));
+
+        }
     }
-
-    h = m_unit->currentText();
-    if( h != m_template->unit().einheitSingular()) {
-      // qDebug () << "Template Einheit dirty -> update to " << h << endl;
-      m_template->setUnitId( UnitManager::self()->getUnitIDSingular(h));
-    }
-
-#if 0
-    // chapter ID is not touched anymore
-    /* compare catalog chapter */
-    int chapterId = 0; // m_katalog->chapterID(cbChapter->currentText()).toInt();
-    // FIXME: need new way of picking hte chapterId bcause of hirarchical.
-
-    if( chapterId != m_template->getChapterID() ) {
-      // qDebug () << "Chapter ID dirty ->update" << endl;
-      if( askChapterChange( m_template, chapterId )) {
-        m_template->setChapterID( chapterId );
-        emit( chapterChanged( chapterId ));
-      }
-    }
-#endif
-    /* count time */
-    bool c = m_addTime->isChecked();
-    if( c != m_template->hasTimeslice() ) {
-      m_template->setHasTimeslice(c);
-    }
-
-    /* benefit */
-    h = spBenefit->cleanText();
-    bool b;
-    double g = h.toDouble( &b );
-    if( b  && g != m_template->getBenefit() ) {
-      m_template->setBenefit(g);
-      // qDebug () << "benefit dirty ->update to " << g << endl;
-    }
-
-    h = cbMwst->currentText();
-    // TODO!
-
-    // Calculationtype
-    int selId = m_gbPriceSrc->checkedId();
-    CatalogTemplate::CalculationType calcType = CatalogTemplate::Unknown;
-    if( selId == 0 ) {
-      calcType = CatalogTemplate::ManualPrice;
-    } else if( selId == 1 ) {
-      calcType = CatalogTemplate::Calculation;
-    } else {
-      // qDebug () << "ERROR: Calculation type not selected, id is " << selId << endl;
-    }
-    m_template->setCalculationType( calcType );
-
-    // reread the manual price
-    double dd = m_manualPriceVal->value();
-    m_template->setManualPrice( Geld( dd ) );
-
-    h = cbChapter->currentText();
-    // qDebug () << "catalog chapter is " << h << endl;
-
-    if( m_template->save() ) {
-      emit( editAccepted( m_template ) );
-      KatalogMan::self()->notifyKatalogChange( m_katalog, m_template->getTemplID() );
-    } else {
-        QMessageBox::warning(0, i18n("Template Error"), i18n("Saving of this template failed, sorry"));
-
-    }
-  }
-  // qDebug () << "*** Saving finished " << endl;
-
-  modified = false;
-  QDialog::accept();
+    // qDebug () << "*** Saving finished " << endl;
+    QDialog::accept();
 }
 
 void FlosTemplDialog::reject()
@@ -399,7 +411,7 @@ void FlosTemplDialog::closeEvent ( QCloseEvent * event )
 
 bool FlosTemplDialog::confirmClose()
 {
-    if(modified == true) {
+    if( templModified() ) {
         QMessageBox msgBox;
         msgBox.setText(i18n("The template has been modified."));
         msgBox.setInformativeText(i18n("Do you want to discard your changes?"));
@@ -443,23 +455,35 @@ bool FlosTemplDialog::askChapterChange( FloskelTemplate*, int )
 
 void FlosTemplDialog::slManualPriceChanged(double dd)
 {
-  // qDebug () << "Changing manual price!" << endl;
+    qDebug () << "Changing manual price:" << dd << endl;
   if( ! m_template ) return;
   // qDebug () << "Updating manual price!" << endl;
   m_template->setManualPrice( Geld( dd ));
   refreshPrices();
 }
 
-
-void FlosTemplDialog::slBenefitChange( int neuPreis )
+double FlosTemplDialog::benefitValue()
 {
-  CalcPartList tpList = m_template->getCalcPartsList( );
-  QListIterator<CalcPart*> it( tpList );
-  while( it.hasNext() ) {
-    CalcPart *cp = it.next();
-    cp->setProzentPlus( neuPreis );
-  }
-  refreshPrices();
+    double val = 0;
+    CalcPartList cparts = m_template->getCalcPartsList();
+
+    // Currently still all calcparts have the same value of benefit.
+    // once this changes, this needs to be fixed accordingly.
+    if( cparts.size() > 0 ) {
+        val = cparts.at(0)->getProzentPlus();
+    }
+
+    return val;
+}
+
+void FlosTemplDialog::slBenefitChange( int newBen )
+{
+    int oldBen = qRound(m_template->getBenefit());
+    if( oldBen != newBen ) {
+        m_template->setBenefit(newBen);
+        refreshPrices();
+        _calcPartsModified = true;
+    }
 }
 
 void FlosTemplDialog::slAddFixPart()
@@ -472,6 +496,8 @@ void FlosTemplDialog::slAddFixPart()
   {
     FixCalcPart *cp = new FixCalcPart( dia.getName(), dia.getPreis());
     cp->setMenge( dia.getMenge());
+    cp->setProzentPlus(benefitValue());
+
     cp->setDirty(true);
 
     QTreeWidgetItem *lvItem = new QTreeWidgetItem( m_fixParts);
@@ -479,6 +505,7 @@ void FlosTemplDialog::slAddFixPart()
     mCalcPartDict.insert( lvItem, cp );
     m_template->addCalcPart( cp );
     refreshPrices();
+    _calcPartsModified = true;
   }
 }
 
@@ -498,6 +525,7 @@ void FlosTemplDialog::slRemoveFixPart()
     delete item;
 
     refreshPrices();
+    _calcPartsModified = true;
   }
 }
 
@@ -526,12 +554,14 @@ void FlosTemplDialog::slEditFixPart()
 void FlosTemplDialog::slFixCalcPartChanged(FixCalcPart *cp)
 {
   refreshPrices();
+  _calcPartsModified = true;
   drawFixListEntry(m_fixParts->currentItem(), cp);
 }
 
 void FlosTemplDialog::slTimeCalcPartChanged(TimeCalcPart *cp)
 {
   refreshPrices();
+  _calcPartsModified = true;
   drawTimeListEntry(m_timeParts->currentItem(), cp);
 }
 
@@ -540,17 +570,20 @@ void FlosTemplDialog::slAddTimePart()
   if( ! m_template ) return;
   TimeCalcDialog dia(this);
 
-  if( dia.exec() == QDialog::Accepted )
-  {
-    TimeCalcPart *cp = new TimeCalcPart( dia.getName(), dia.getDauer(), 0 );
+  if( dia.exec() == QDialog::Accepted ) {
+    TimeCalcPart *cp = new TimeCalcPart( dia.getName(), dia.getDauer(),
+                                         TimeCalcPart::timeUnitFromString(dia.unitStr()),
+                                         0 );
     cp->setGlobalStdSetAllowed( dia.allowGlobal());
     StdSatz std = StdSatzMan::self()->getStdSatz( dia.getStundensatzName());
     cp->setStundensatz( std );
+    cp->setProzentPlus(benefitValue());
     QTreeWidgetItem *lvItem = new QTreeWidgetItem( m_timeParts);
     drawTimeListEntry( lvItem, cp );
     mCalcPartDict.insert( lvItem, cp );
     m_template->addCalcPart( cp );
     refreshPrices();
+    _calcPartsModified = true;
   }
 }
 
@@ -565,7 +598,8 @@ void FlosTemplDialog::drawTimeListEntry( QTreeWidgetItem *it, TimeCalcPart *cp )
     return;
 
   it->setText( 0, cp->getName());
-  it->setText( 1, i18n("%1 Min.").arg(cp->getMinuten()));
+  it->setText( 1, QString::number(cp->duration())
+               + QLatin1Char(' ') + TimeCalcPart::timeUnitString(cp->timeUnit()));
   it->setText( 2, cp->getStundensatz().getName());
   it->setText( 3, cp->globalStdSetAllowed() ? i18n("Yes") : i18n("No"));
 }
@@ -585,7 +619,7 @@ void FlosTemplDialog::drawMatListEntry( QTreeWidgetItem *it, MaterialCalcPart *m
 {
   it->setText( 0, mc->getName());
   it->setText( 1, QString::number(mc->getCalcAmount(), 'f',2));
-  it->setText( 2, mc->getMaterial()->getUnit().einheitSingular());
+  it->setText( 2, mc->getMaterial()->unit().einheitSingular());
   it->setText( 3, mc->basisKosten().toString( m_katalog->locale() ));
   it->setText( 4, QString::number(mc->getMaterial()->getAmountPerPack(), 'f',2));
   it->setText( 5, mc->getMaterial()->salesPrice().toString( m_katalog->locale() ));
@@ -608,6 +642,7 @@ void FlosTemplDialog::slRemoveTimePart()
     delete item;
 
     refreshPrices();
+    _calcPartsModified = true;
   }
 }
 
@@ -634,6 +669,7 @@ void FlosTemplDialog::slEditTimePart()
     // qDebug () << "No current Item!";
   }
   refreshPrices();
+  _calcPartsModified = true;
 }
 
 /*
@@ -657,18 +693,23 @@ void FlosTemplDialog::slAddMatPart()
  */
 void FlosTemplDialog::slNewMaterial( int matID, double amount )
 {
-  // qDebug () << "Material ID: " << matID << endl;
+    // qDebug () << "Material ID: " << matID << endl;
 
-  // TODO: Checken, ob der richtige Tab aktiv ist.
-  // TODO: Check if the material is already in the calcpart (is this really needed??)
-  MaterialCalcPart *mc;
+    // TODO: Checken, ob der richtige Tab aktiv ist.
+    // TODO: Check if the material is already in the calcpart (is this really needed??)
+    MaterialCalcPart *mc;
 
-  mc = new MaterialCalcPart(matID, 0, amount);
-  m_template->addCalcPart( mc );
-  QTreeWidgetItem *lvItem = new QTreeWidgetItem(m_matParts);
-  drawMatListEntry( lvItem, mc );
-  mCalcPartDict.insert( lvItem, mc );
-  refreshPrices();
+    mc = new MaterialCalcPart(matID, 0, amount);
+    if( mc ) {
+        mc->setProzentPlus(benefitValue());
+
+        m_template->addCalcPart( mc );
+        QTreeWidgetItem *lvItem = new QTreeWidgetItem(m_matParts);
+        drawMatListEntry( lvItem, mc );
+        mCalcPartDict.insert( lvItem, mc );
+        refreshPrices();
+        _calcPartsModified = true;
+    }
 }
 
 
@@ -698,6 +739,7 @@ void FlosTemplDialog::slMatCalcPartChanged(MaterialCalcPart *mc)
 {
   drawMatListEntry(m_matParts->currentItem(), mc);
   refreshPrices();
+  _calcPartsModified = true;
 }
 
 void FlosTemplDialog::slRemoveMatPart()
@@ -716,61 +758,49 @@ void FlosTemplDialog::slRemoveMatPart()
     delete item;
 
     refreshPrices();
+    _calcPartsModified = true;
   }
 }
 
 /*
- * dieser Slot wird betreten, wenn der Radiobutton Kalkulierter
- * Preis/Manueller Preis umgeschaltet wird.
+ * Slot for managing the switch from manual to calculated price
+ * and vice versa
  */
 void FlosTemplDialog::slCalcOrFix(int button)
 {
   bool ok = true;
+  bool manualEnabled = true;
 
-  if( button == 0 )
-  {
-    /* auf manuell geschaltet */
-    if( m_template )
-      m_template->setCalculationType( CatalogTemplate::ManualPrice );
-
-    m_manualPriceVal->setEnabled( true );
-
-    m_textTimePart->setEnabled(false);
-    m_textFixPart->setEnabled(false);
-    m_textMaterialPart->setEnabled(false);
-
-    m_tLabelMat->setEnabled(false);
-    m_tLabelFix->setEnabled(false);
-    m_tLabelTime->setEnabled(false);
-    spBenefit->setEnabled(false);
-  }
-  else if( button == 1 )
-  {
-    /* auf kalkuliert geschaltet */
-    if( m_template )
+  if( button == 0 ) {
+    /* switched to manual price */
+    if( m_template ) {
+        m_template->setCalculationType( CatalogTemplate::ManualPrice );
+    }
+  } else if( button == 1 ) {
+    /* switched to calculated */
+    if( m_template ) {
       m_template->setCalculationType( CatalogTemplate::Calculation );
-
-    m_manualPriceVal->setEnabled( false );
-
-    m_textTimePart->setEnabled(true);
-    m_textFixPart->setEnabled(true);
-    m_textMaterialPart->setEnabled(true);
-
-    m_tLabelMat->setEnabled(true);
-    m_tLabelFix->setEnabled(true);
-    m_tLabelTime->setEnabled(true);
-    spBenefit->setEnabled(true);
-  }
-  else
-  {
-    /* unbekannter knopf -> fehler */
-    // qDebug () << "--- Error: Falsche Button ID " << button <<  endl;
+    }
+    manualEnabled = false;
+  } else {
+    /* unknown knob*/
     ok = false;
   }
 
-  if( ok )
-  {
-    refreshPrices();
+  if( ok ) {
+      m_manualPriceVal->setEnabled( manualEnabled );
+
+      m_textTimePart->setEnabled(!manualEnabled);
+      m_textFixPart->setEnabled(!manualEnabled);
+      m_textMaterialPart->setEnabled(!manualEnabled);
+
+      m_tLabelMat->setEnabled(!manualEnabled);
+      m_tLabelFix->setEnabled(!manualEnabled);
+      m_tLabelTime->setEnabled(!manualEnabled);
+      m_tLabelProfit->setEnabled(!manualEnabled);
+      spBenefit->setEnabled(!manualEnabled);
+
+      refreshPrices();
   }
 }
 
