@@ -17,36 +17,15 @@
 #include <stdlib.h>
 // include files for QT
 #include <QtGui>
+#include <QMenu>
+#include <QProgressBar>
+#include <QDebug>
+#include <QStatusBar>
 
 // include files for KDE
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
-#include <kmenu.h>
-#include <kstatusbar.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kactioncollection.h>
-#include <kstandardshortcut.h>
-#include <kstandardaction.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kshortcut.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-#include <kactioncollection.h>
-#include <kactionmenu.h>
-#include <kglobal.h>
 #include <kxmlguifactory.h>
 #include <KXmlGuiWindow>
+#include <KActionCollection>
 
 // application specific includes
 #include "katalogview.h"
@@ -94,10 +73,9 @@ void KatalogView::init(const QString& katName )
   KatalogListView *listview = getListView();
 
   if( ! listview ) {
-      kDebug() << "ERROR: No listview created !!!" << endl;
+      // qDebug () << "ERROR: No listview created !!!" << endl;
   } else {
-      m_filterHead = new FilterHeader(listview, w);
-      m_filterHead->showCount(false);
+      m_filterHead = new FilterHeader(w, listview);
       box->insertWidget(0, m_filterHead);
 
       connect( listview, SIGNAL(currentItemChanged ( QTreeWidgetItem*, QTreeWidgetItem*)),
@@ -121,7 +99,7 @@ void KatalogView::init(const QString& katName )
 
   setCentralWidget(w);
   m_editListViewItem = 0;
-  kDebug() << "Getting katalog!" << katName << endl;
+  // qDebug () << "Getting katalog!" << katName << endl;
 
   setAutoSaveSettings( QString::fromLatin1( "CatalogWindow" ),  true );
 }
@@ -171,39 +149,39 @@ void KatalogView::initActions()
 {  
   m_acEditChapter = actionCollection()->addAction( "edit_chapter", this, SLOT( slEditSubChapter() ) );
   m_acEditChapter->setText( i18n("Edit Sub chapter") );
-  m_acEditChapter->setIcon( KIcon("folder-documents"));
+  m_acEditChapter->setIcon( QIcon::fromTheme("folder-documents"));
   m_acEditChapter->setStatusTip(i18n("Edit a catalog sub chapter"));
   m_acEditChapter->setEnabled(true);
 
   m_acAddChapter = actionCollection()->addAction( "add_chapter", this, SLOT( slAddSubChapter() ) );
   m_acAddChapter->setText( i18n("Add a sub chapter") );
-  m_acAddChapter->setIcon( KIcon("document-edit"));
+  m_acAddChapter->setIcon( QIcon::fromTheme("document-edit"));
   m_acAddChapter->setStatusTip(i18n("Add a sub chapter below the selected one"));
   m_acAddChapter->setEnabled(false);
 
   m_acRemChapter = actionCollection()->addAction( "remove_chapter", this, SLOT( slRemoveSubChapter() ) );
   m_acRemChapter->setText( i18n("Remove a sub chapter") );
-  m_acRemChapter->setIcon( KIcon("document-edit"));
+  m_acRemChapter->setIcon( QIcon::fromTheme("document-edit"));
   m_acRemChapter->setStatusTip(i18n("Remove a sub chapter"));
   m_acRemChapter->setEnabled(false);
 
   m_acEditItem = actionCollection()->addAction( "edit_template", this, SLOT( slEditTemplate() ) );
   m_acEditItem->setText( i18n("Edit template") );
-  m_acEditItem->setIcon( KIcon("document-edit"));
+  m_acEditItem->setIcon( QIcon::fromTheme("document-edit"));
   m_acEditItem->setStatusTip(i18n("Opens the editor window for templates to edit the selected one"));
   m_acEditItem->setEnabled(false);
 
   m_acNewItem = actionCollection()->addAction( "new_template", this, SLOT( slNewTemplate() ) );
   m_acNewItem->setText( i18n("New template") );
-  m_acNewItem->setShortcut( KStandardShortcut::shortcut(KStandardShortcut::New) );
-  m_acNewItem->setIcon( KIcon("document-new"));
+  m_acNewItem->setShortcut( QKeySequence::New );
+  m_acNewItem->setIcon( QIcon::fromTheme("document-new"));
   m_acNewItem->setStatusTip(i18n("Opens the editor window for templates to enter a new template"));
   m_acNewItem->setEnabled(true);
 
   m_acDeleteItem = actionCollection()->addAction( "delete_template", this, SLOT( slDeleteTemplate() ) );
   m_acDeleteItem->setText( i18n("Delete template") );
-  m_acDeleteItem->setShortcut( KStandardShortcut::shortcut(KStandardShortcut::Clear) );
-  m_acDeleteItem->setIcon( KIcon("document-delete"));
+  m_acDeleteItem->setShortcut( QKeySequence::Delete);
+  m_acDeleteItem->setIcon( QIcon::fromTheme("document-delete"));
   m_acDeleteItem->setStatusTip(i18n("Deletes the template"));
   m_acDeleteItem->setEnabled(true);
 
@@ -212,38 +190,17 @@ void KatalogView::initActions()
   m_acExport->setStatusTip(i18n("Export the whole catalog as XML encoded file"));
   m_acExport->setEnabled(false); // FIXME: Repair XML Export
 
-  m_acFileClose = actionCollection()->addAction( KStandardAction::Close, this, SLOT( slotFileClose() ) );
-  m_acFileClose->setStatusTip( i18n("Close the katalog view"));
-
-  m_acFilePrint = actionCollection()->addAction( KStandardAction::Print, this, SLOT( slotFilePrint() ) );
-  m_acFilePrint ->setStatusTip( i18n("Prints out the current document"));
-  m_acFilePrint->setEnabled(false);
-
-  m_acEditCut = actionCollection()->addAction( KStandardAction::Cut, this, SLOT( slotEditCut() ) );
-  m_acEditCut->setStatusTip(i18n("Cuts the selected section and puts it to the clipboard"));
-  m_acEditCut->setEnabled(false);
-
-  m_acEditCopy = actionCollection()->addAction( KStandardAction::Copy, this, SLOT( slotEditCopy() ) );
-  m_acEditCopy->setStatusTip(i18n("Copies the selected section to the clipboard"));
-  m_acEditCopy->setEnabled(false);
-
-  m_acEditPaste = actionCollection()->addAction( KStandardAction::Paste, this, SLOT( slotEditPaste() ) );
-  m_acEditPaste->setStatusTip(i18n("Pastes the clipboard contents to current position"));
-  m_acEditPaste->setEnabled(false);
-  // createStandardStatusBarAction();
-  // setStandardToolBarMenuEnabled( true );
-
   // use the absolute path to your kraftui.rc file for testing purpose in createGUI();
-  char *prjPath = getenv( "KRAFT_HOME" );
-  if( prjPath ) {
-      createGUI(QString(prjPath)+"/src/katalogview.rc");
+  QString prjPath = QString::fromUtf8(qgetenv( "KRAFT_HOME" ));
+  if( !prjPath.isEmpty() ) {
+      createGUI(prjPath + QLatin1String("/src/katalogview.rc"));
   } else {
       createGUI("katalogview.rc");
   }
 
 }
 
-void KatalogView::openDocumentFile(const KUrl& )
+void KatalogView::openDocumentFile(const QUrl& )
 {
   slotStatusMsg(i18n("Opening file..."));
 
@@ -260,96 +217,13 @@ bool KatalogView::queryExit()
   return true;
 }
 
-/////////////////////////////////////////////////////////////////////
-// SLOT IMPLEMENTATION
-/////////////////////////////////////////////////////////////////////
-
-void KatalogView::slotFileNewWindow()
-{
-  slotStatusMsg(i18n("Opening a new katalog window..."));
-
-  KatalogView *new_window= new KatalogView();
-  new_window->show();
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-
-void KatalogView::slotFileOpen()
-{
-  slotStatusMsg(i18n("Opening file..."));
-
-  KUrl url=KFileDialog::getOpenUrl( KUrl(),
-                                   i18n("*|All files"), this, i18n("Open File..."));
-  if(!url.isEmpty())
-  {
-      // doc->openDocument(url);
-      setCaption(url.fileName(), false);
-    }
-  slotStatusMsg(i18n("Ready."));
-}
-
-
-void KatalogView::slotFileSave()
-{
-  slotStatusMsg(i18n("Saving file..."));
-
-  // doc->saveDocument(doc->URL());
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-
-void KatalogView::slotFileClose()
-{
-  slotStatusMsg(i18n("Closing file..."));
-
-  close();
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-void KatalogView::slotFilePrint()
-{
-  slotStatusMsg(i18n("Printing..."));
-
-#if 0
-  QPrinter printer;
-  if (printer.setup(this))
-  {
-  }
-#endif
-  slotStatusMsg(i18n("Ready."));
-}
-
-
-void KatalogView::slotEditCut()
-{
-  slotStatusMsg(i18n("Cutting selection..."));
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-void KatalogView::slotEditCopy()
-{
-  slotStatusMsg(i18n("Copying selection to clipboard..."));
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-void KatalogView::slotEditPaste()
-{
-  slotStatusMsg(i18n("Inserting clipboard contents..."));
-
-  slotStatusMsg(i18n("Ready."));
-}
-
 void KatalogView::slotStatusMsg(const QString &text)
 {
-  ///////////////////////////////////////////////////////////////////
-  // change status message permanently
-  statusBar()->clearMessage();
-  statusBar()->changeItem(text, ID_STATUS_MSG);
+    if( text.isEmpty() ) {
+        statusBar()->clearMessage();
+    } else {
+        statusBar()->showMessage(text, 30*1000 /* milliseconds timeout */ );
+    }
 }
 
 void KatalogView::slTreeviewItemChanged( QTreeWidgetItem *newItem, QTreeWidgetItem * /* prevItem */ )
@@ -422,7 +296,7 @@ void KatalogView::slRemoveSubChapter()
 void KatalogView::slotShowTemplateDetails( CatalogTemplate *tmpl )
 {
   if( ! (mTemplateText && mTemplateStats) ) {
-    kDebug() << "Hoover-Text: No label ready.";
+    // qDebug () << "Hoover-Text: No label ready.";
     return;
   }
 
@@ -432,7 +306,7 @@ void KatalogView::slotShowTemplateDetails( CatalogTemplate *tmpl )
     return;
   }
 
-  KLocale *locale = DefaultProvider::self()->locale();
+  QLocale *locale = DefaultProvider::self()->locale();
 
   QString t;
   QString flos = tmpl->getText();
@@ -443,13 +317,13 @@ void KatalogView::slotShowTemplateDetails( CatalogTemplate *tmpl )
   mTemplateText->setText( t );
 
   t = "<table border=\"0\">";
-  t += i18n("<tr><td>Created at:</td><td>%1</td><td>&nbsp;&nbsp;</td><td>Last used:</td><td>%2</td></tr>" )
-       .arg( locale->formatDateTime( tmpl->enterDate() ) )
-       .arg( locale->formatDateTime( tmpl->lastUsedDate() ) );
-  t += i18n("<tr><td>Modified at:</td><td>%1</td><td>&nbsp;&nbsp;</td><td>Use Count:</td><td>%2</td></tr>" )
-       .arg( locale->formatDateTime( tmpl->modifyDate() ) )
-       .arg( tmpl->useCounter() );
+  t += i18n("<tr><td>Created at:</td><td>%1</td></tr>" ) /* <td>&nbsp;&nbsp;</td><td>Last used:</td><td>%2</td></tr>" ) */
+       .arg( locale->toString( tmpl->enterDate() ) );
+       /* .arg( locale->formatDateTime( tmpl->lastUsedDate() ) ); */
+  t += i18n("<tr><td>Modified at:</td><td>%1</td></tr>") /* <td>&nbsp;&nbsp;</td><td>Use Count:</td><td>%2</td></tr>" ) */
+       .arg( locale->toString( tmpl->modifyDate() ) );
+       /* .arg( tmpl->useCounter() ); */
   t += "</table>";
-  // kDebug() << "Hoover-String: " << t;
+  // qDebug() << "Hoover-String: " << t;
   mTemplateStats->setText( t );
 }
