@@ -91,7 +91,7 @@ QTreeWidgetItem* MaterialKatalogListView::addMaterialToView( QTreeWidgetItem *pa
     recItem->setCheckState(0, Qt::Unchecked);
   }
   //recItem->setFlags( flags );
-  recItem->setText( 0, mat->name() );
+  recItem->setText( 0, mat->getText() );
   // recItem->setMultiLinesEnabled( true );  FIXME
   slFreshupItem( recItem,  mat, catalog()->locale() );
   m_dataDict.insert( recItem, mat );
@@ -104,9 +104,9 @@ void MaterialKatalogListView::slFreshupItem( QTreeWidgetItem *item, void* templ,
   StockMaterial *mat = static_cast<StockMaterial*>( templ );
 
   if ( item && mat ) {
-    Einheit e = mat->getUnit();
+    Einheit e = mat->unit();
     // qDebug () << "Setting material name " << e.einheitSingular() << endl;
-    item->setText( 0, mat->name() );
+    item->setText( 0, mat->getText() );
     item->setText( 1, QString::number( mat->getAmountPerPack() ) );
     item->setText( 2, e.einheit( mat->getAmountPerPack() ) );
     item->setText( 3, mat->purchPrice().toString( loc ) );
@@ -129,8 +129,8 @@ DocPosition MaterialKatalogListView::itemToDocPosition( QTreeWidgetItem *item )
   // FIXME
   StockMaterial *mat = static_cast<StockMaterial*>( m_dataDict[item] );
   if ( mat ) {
-    pos.setText( mat->name() );
-    pos.setUnit( mat->getUnit() );
+    pos.setText( mat->getText() );
+    pos.setUnit( mat->unit() );
     pos.setUnitPrice( mat->salesPrice() );
   }
 
