@@ -102,8 +102,7 @@ void ModelTest::nonDestructiveBasicTest()
     fetchingMore = true;
     model->fetchMore(QModelIndex());
     fetchingMore = false;
-    Qt::ItemFlags flags = model->flags(QModelIndex());
-    Q_ASSERT(flags == Qt::ItemIsDropEnabled || flags == 0);
+    // Q_ASSERT(flags == Qt::ItemIsDropEnabled || flags == 0);
     model->hasChildren(QModelIndex());
     model->hasIndex(0, 0);
     model->headerData(0, Qt::Horizontal);
@@ -184,9 +183,9 @@ void ModelTest::hasIndex()
     Q_ASSERT(model->hasIndex(0, -2) == false);
 
     int rows = model->rowCount();
-    int columns = model->columnCount();
 
     // check out of bounds
+    int columns = model->columnCount();
     Q_ASSERT(model->hasIndex(rows, columns) == false);
     Q_ASSERT(model->hasIndex(rows + 1, columns + 1) == false);
 
@@ -208,12 +207,12 @@ void ModelTest::index()
     Q_ASSERT(model->index(0, -2) == QModelIndex());
 
     int rows = model->rowCount();
-    int columns = model->columnCount();
 
     if (rows == 0)
         return;
 
     // Catch off by one errors
+    int columns = model->columnCount();
     Q_ASSERT(model->index(rows, columns) == QModelIndex());
     Q_ASSERT(model->index(0, 0).isValid() == true);
 
@@ -420,7 +419,7 @@ void ModelTest::data()
     QVariant textAlignmentVariant = model->data(model->index(0, 0), Qt::TextAlignmentRole);
     if (textAlignmentVariant.isValid()) {
         int alignment = textAlignmentVariant.toInt();
-       Q_ASSERT(alignment == (alignment & (Qt::AlignHorizontal_Mask | Qt::AlignVertical_Mask)));
+        Q_ASSERT(alignment == (alignment & (Qt::AlignHorizontal_Mask | Qt::AlignVertical_Mask)));
     }
 
     // General Purpose roles that should return a QColor
