@@ -151,7 +151,7 @@ void Portal::initActions()
   actEditTemplates->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_E ));
 
   QAction *reconfDb = actionCollection()->addAction( "reconfigure_db", this, SLOT( slotReconfigureDatabase() ) );
-  reconfDb->setText("Redo Initial Setup...");
+  reconfDb->setText(i18n("Redo Initial Setup..."));
   reconfDb->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_R ));
 
   fileQuit->setStatusTip(i18n("Quits the application"));
@@ -266,17 +266,17 @@ void Portal::slotStartupChecks()
         if ( err.text().contains( "Can't connect to local MySQL server through socket" ) ) {
             text = i18n( "Kraft can not connect to the specified MySQL server. "
                          "Please check the Kraft database settings, check if the server is "
-                         "running and verify if a database with the name %1 exits!" ).arg( dbName );
+                         "running and verify if a database with the name %1 exits!" , dbName );
         } else if ( err.text().contains( "Unknown database '" + dbName + "' QMYSQL3: Unable to connect" ) ) {
             text = i18n( "The database with the name %1 does not exist on the database server. "
                          "Please make sure the database exists and is accessible by the user "
-                         "running Kraft." ).arg( dbName );
+                         "running Kraft.", dbName );
         } else if ( err.text().contains( "Driver not loaded" ) ) {
             text = i18n( "The Qt database driver could not be loaded. That probably means, that "
                          "they are not installed. Please make sure the Qt database packages are "
                          "installed and try again." );
         } else {
-            text = i18n( "There is a database problem: %1" ).arg( err.text() );
+            text = i18n( "There is a database problem: %1", err.text() );
         }
 
         m_portalView->systemInitError( m_portalView->ptag( text, "problem" ) );
@@ -388,7 +388,7 @@ void Portal::slotReceivedMyAddress( const QString& uid, const KContacts::Address
 
     QString name = myContact.formattedName();
     if( !name.isEmpty() ) {
-        name = i18n("Welcome to Kraft, %1").arg(name);
+        name = i18n("Welcome to Kraft, %1", name);
         statusBar()->showMessage(name, 30*1000);
     }
 }
@@ -598,15 +598,36 @@ void Portal::slotMailPdfAvailable( const QString& fileName )
     _pdfFileName = fi.canonicalFilePath();
 
     // get the email.
+    bool noEmail = true;
     if( !_clientId.isEmpty() && mAddressProvider ) {
         connect( mAddressProvider, SIGNAL(lookupResult(QString,KContacts::Addressee)),
                  this, SLOT(slotMailAddresseeFound(QString, KContacts::Addressee)));
-        mAddressProvider->lookupAddressee(_clientId);
+        AddressProvider::LookupState state = mAddressProvider->lookupAddressee( _clientId);
+        switch( state ) {
+        case AddressProvider::LookupFromCache: {
+            const KContacts::Addressee contact = mAddressProvider->getAddresseeFromCache(_clientId);
+            slotMailAddresseeFound(_clientId, contact);
+            noEmail = false;
+            break;
+        }
+        case AddressProvider::LookupNotFound:
+        case AddressProvider::ItemError:
+        case AddressProvider::BackendError: {
+            // No EMail available.
+            break;
+        }
+        case AddressProvider::LookupOngoing:
+        case AddressProvider::LookupStarted:
+            // Not much to do, just wait for the lookup slot to arrive
+            noEmail = false;
+            break;
+        }
         _clientId.clear();
-    } else {
-        slotMailAddresseeFound( QString::null, KContacts::Addressee() );
     }
 
+    if( noEmail ){
+        slotMailAddresseeFound( QString::null, KContacts::Addressee() );
+    }
 }
 
 void Portal::slotMailAddresseeFound( const QString& uid, const KContacts::Addressee& contact )
@@ -618,18 +639,33 @@ void Portal::slotMailAddresseeFound( const QString& uid, const KContacts::Addres
         mailReceiver = contact.fullEmail(); // the prefered email
     }
 
+    if( mailReceiver.isEmpty() ) {
+        QMessageBox::warning( this, i18n("Send per Email"),
+                              i18n("The email address of the contact is empty!\n"
+                                   "Please add an email address to the addressbook."));
+        return;
+    }
+
     // qDebug () << "Found mail address " << mailReceiver << " for " << uid;
 
     // qDebug () << "Mailing away " << _pdfFileName << endl;
 
     disconnect( mAddressProvider, SIGNAL(lookupResult(QString,KContacts::Addressee)),
              this, SLOT(slotMailAddresseeFound(QString, KContacts::Addressee)));
-    disconnect( ReportGenerator::self(), SIGNAL( pdfAvailable( const QString& ) ),0,0 );
+    disconnect( ReportGenerator::self(), SIGNAL( pdfAvailable( const QString& ) ), nullptr, nullptr );
 
-    QString mailAgent("thunderbird");
-    if( mailAgent.contains("thunderbird") ) {
-        QString prog = "/usr/bin/thunderbird";
-        QStringList args;
+    QStringList args;
+    QString prog;
+
+    if( KraftSettings::self()->mailUA().startsWith("xdg") ) {
+        args.append( "--utf8");
+        args.append( "--attach");
+        args.append(_pdfFileName );
+        args.append( mailReceiver);
+        prog = QLatin1String("/usr/bin/xdg-email");
+    } else {
+        // Fallback to thunderbird
+        prog = QLatin1String("/usr/bin/thunderbird");
 
         args.append("-compose");
         QString tmp;
@@ -638,14 +674,11 @@ void Portal::slotMailAddresseeFound( const QString& uid, const KContacts::Addres
         }
         tmp += QString("attachment='file://%1'").arg(_pdfFileName);
         args.append(tmp);
+    }
+    qDebug () << "Starting mailer: " << prog << args;
 
-        // qDebug () << "Starting thunderbird: " << prog << args;
-
-        if (!QProcess::startDetached(prog, args)) {
-            // qDebug () << "Failed to start thunderbird composer!";
-        }
-    } else {
-       // FIXME porting
+    if (!QProcess::startDetached(prog, args)) {
+        qDebug () << "Failed to start thunderbird composer!";
     }
     _pdfFileName.clear();
 }
@@ -668,7 +701,7 @@ void Portal::slotPrintDocument( const QString& id,  const dbID& archID )
 
 void Portal::slotOpenPdf( const QString& fileName )
 {
-    disconnect( ReportGenerator::self(), SIGNAL( pdfAvailable( const QString& ) ),0,0 );
+    disconnect( ReportGenerator::self(), SIGNAL( pdfAvailable( const QString& ) ),nullptr, nullptr );
     QUrl url( fileName );
     QDesktopServices::openUrl(url);
 
@@ -703,7 +736,7 @@ void Portal::slotOpenPdf( const QString& fileName )
 
 void Portal::slotOpenDocument( const QString& id )
 {
-  slotStatusMsg( i18n("Opening document %1").arg(id ) );
+  slotStatusMsg( i18n("Opening document %1", id ) );
   // qDebug () << "Opening document " << id;
   if( !id.isEmpty() ) {
     DocumentMan *docman = DocumentMan::self();
@@ -961,7 +994,7 @@ void Portal::slotOpenKatalog(const QString& kat)
     } else {
       QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
 
-      KatalogView *katView = 0;
+      KatalogView *katView = nullptr;
       if( kat == MaterialKatalogView::MaterialCatalogName ) {
 
         /* Materialkatalog */
@@ -1009,9 +1042,9 @@ QString Portal::textWrap( const QString& t, int width )
     }
     else
     {
-        unsigned int start = 0;
+        int start = 0;
         int pos = width;
-        while( pos < (int) t.length() )
+        while( pos < t.length() )
         {
             pos = t.indexOf( ' ', start+width );
             if( pos > -1 ) {
